
/* Generated data (by glib-mkenums) */


/* --- bseexports.h --- */
  { "BseExportNodeType", G_TYPE_ENUM, &BSE_TYPE_ID (BseExportNodeType), bse_export_node_type_values },

/* --- bsebiquadfilter.h --- */
  { "BseBiquadFilterType", G_TYPE_ENUM, &BSE_TYPE_ID (BseBiquadFilterType), bse_biquad_filter_type_values },
  { "BseBiquadFilterNorm", G_TYPE_ENUM, &BSE_TYPE_ID (BseBiquadFilterNorm), bse_biquad_filter_norm_values },

/* --- bseenums.h --- */
  { "BseRegistrationType", G_TYPE_ENUM, &BSE_TYPE_ID (BseRegistrationType), bse_registration_type_values },
  { "BseInterpolType", G_TYPE_ENUM, &BSE_TYPE_ID (BseInterpolType), bse_interpol_type_values },
  { "BseLoopType", G_TYPE_ENUM, &BSE_TYPE_ID (BseLoopType), bse_loop_type_values },
  { "BseMagicFlags", G_TYPE_FLAGS, &BSE_TYPE_ID (BseMagicFlags), bse_magic_flags_values },
  { "BseErrorType", G_TYPE_ENUM, &BSE_TYPE_ID (BseErrorType), bse_error_type_values },

/* --- bseglobals.h --- */
  { "BseTimeRangeType", G_TYPE_ENUM, &BSE_TYPE_ID (BseTimeRangeType), bse_time_range_type_values },

/* --- bsemidievent.h --- */
  { "BseMidiEventType", G_TYPE_ENUM, &BSE_TYPE_ID (BseMidiEventType), bse_midi_event_type_values },

/* --- bseproject.h --- */
  { "BseProjectState", G_TYPE_ENUM, &BSE_TYPE_ID (BseProjectState), bse_project_state_values },

/* --- bsestandardosc.h --- */
  { "BseStandardOscWaveType", G_TYPE_ENUM, &BSE_TYPE_ID (BseStandardOscWaveType), bse_standard_osc_wave_type_values },

/* --- bsemididecoder.h --- */
  { "BseMidiDecoderState", G_TYPE_ENUM, &BSE_TYPE_ID (BseMidiDecoderState), bse_midi_decoder_state_values },

/* Generated data ends here */

